@@ -1,5 +1,5 @@
 /******************************************************************************
- *  Copyright (C) 2005-2016 by                                                *
+ *  Copyright (C) 2005-2018 by                                                *
  *    Bjoern Erik Nilsen (bjoern.nilsen@bjoernen.com),                        *
  *    Fredrik Berg Kjoelstad (fredrikbk@hotmail.com),                         *
  *    Ralf Lange (ralf.lange@longsoft.de)                                     *
@@ -53,12 +53,6 @@ public:
         InTempPath,
     };
 
-    enum ImageTransformationMode {
-        ScaleImage,      // Scale the image to the output size
-        ClipImage,       // Clip the image to the output size according to the adjustment setting
-        ZoomImage,       // Zoom the image to the output size according to the zoom setting
-    };
-
     /**
      * Initializes the variables of the animation to starting values.
      * @param f The frontend of the application.
@@ -146,6 +140,56 @@ public:
      */
     void setRecordingMode(int newRecordingMode);
 
+    /**
+     * Get the unit mode.
+     * @return The unit mode.
+     */
+    int getUnitMode() const;
+
+    /**
+     * Set the unit mode.
+     * @param mode The new unit mode.
+     */
+    void setUnitMode(int mode);
+
+    /**
+     * Get the unit count.
+     * @return The unit count.
+     */
+    int getUnitCount() const;
+
+    /**
+     * Set the unit count.
+     * @param count The new unit count.
+     */
+    void setUnitCount(int count);
+
+    /**
+     * Get the beep checkbox state.
+     * @brief getBeepState
+     * @return The actual beep checkbox state
+     */
+    bool getBeepState() const;
+
+    /**
+     * Set the beep checkbox state.
+     * @brief setBeepState
+     * @param state The new beep checkbox state.
+     */
+    void setBeepState(bool state);
+
+    /**
+     * Get the beep unit count.
+     * @return The beep unit count.
+     */
+    int getBeepCount() const;
+
+    /**
+     * Set the beep unit count.
+     * @param count The new beep unit count.
+     */
+    void setBeepCount(int count);
+
     /**
      * Get the index of the active video source device of the project.
      * @return active video source.
@@ -194,30 +238,6 @@ public:
      */
     void setMixCount(int newMixCount);
 
-    /**
-     * Get the active playback count of the project.
-     * @return active playback count.
-     */
-    int getPlaybackCount() const;
-
-    /**
-     * Set the active playback count of the project.
-     * @param newPlaybackCount the new playback count source.
-     */
-    void setPlaybackCount(int newPlaybackCount);
-
-    /**
-     * Get the active unit of the project.
-     * @return active unit mode.
-     */
-    int getUnitMode() const;
-
-    /**
-     * Set the active unit mode of the project.
-     * @param newUnitMode the new unit mode.
-     */
-    void setUnitMode(int newUnitMode);
-
     /**
      * Get the overlay intensity value.
      * @return The overlay intensity value.
@@ -298,25 +318,25 @@ public:
      * Get the zoom value of the project.
      * @return Zoom value.
      */
-    int getZoomValue();
+    double getZoomValue();
 
     /**
      * Set the zoom value of the project.
      * @param newZV The new zoom value.
      */
-    void setZoomValue(int newZV);
+    void setZoomValue(double newZV);
 
     /**
      * Get the live view fps of the project.
      * @return live view fps value.
      */
-    int getLiveViewFps();
+    double getLiveViewFps();
 
     /**
      * Set the live view fps of the project.
      * @param newValue The new live view fps value.
      */
-    void setLiveViewFps(int newValue);
+    void setLiveViewFps(double newValue);
 
     /**************************************************************************
      * Video export preferences
@@ -470,20 +490,6 @@ public:
      */
     // void animationChanged(const QString &alteredFile);
 
-    /**
-     * Exports the current project to a video file as specified by the video encoder.
-     * @param encoder the video encoder to use for export to video
-     * @return true on success, false otherwise
-     */
-    bool exportToVideo(VideoEncoder *encoder);
-
-    /**
-     * Exports the current project to a cinelerra-cv project.
-     * @param file the cinelerra-cv project file
-     * @return true on success, false otherwise
-     */
-    bool exportToCinelerra(const QString &file);
-
     /**
      * Get the data of the settings from the project file
      */
@@ -907,6 +913,26 @@ private:
      */
     int recordingMode;
 
+    /**
+     * Active unit mode of the project.
+     */
+    int unitMode;
+
+    /**
+     * Active unit count of the project.
+     */
+    int unitCount;
+
+    /**
+     * Active beep state of the project.
+     */
+    bool beepState;
+
+    /**
+     * Active beep count of the project.
+     */
+    int beepCount;
+
     /**
      * Index of the active video source device of the project.
      */
@@ -927,11 +953,6 @@ private:
      */
     int mixCount;
 
-    /**
-     * Active playback count of the project.
-     */
-    int playbackCount;
-
     /**
      * Active encoder application of the project.
      */
@@ -965,12 +986,12 @@ private:
     /**
      * Active zoom value of the project.
      */
-    int zoomValue;
+    double zoomValue;
 
     /**
      * Active live view fps of the project.
      */
-    int liveViewFps;
+    double liveViewFps;
 
     /**
      * Active video format of the project.
@@ -997,11 +1018,6 @@ private:
      */
     QString defaultOutputFileName;
 
-    /**
-     * Active unit mode of the project.
-     */
-    int unitMode;
-
     /**
      * Active overlay value of the project.
      */
