@@ -97,6 +97,7 @@ MainWindowGUI::MainWindowGUI(QApplication *stApp, Frontend *f)
     whatsthisAct         = 0;
     helpAct              = 0;
     onlineHelpAct        = 0;
+    supportUsAct         = 0;
     aboutQtAct           = 0;
     aboutAct             = 0;
 
@@ -204,13 +205,14 @@ void MainWindowGUI::retranslateStrings()
     // copyAct->setText(tr("&Copy"));
     // pasteAct->setText(tr("&Paste"));
     preferencesAct->setText(tr("Preferences"));
-    whatsthisAct->setText(tr("What's &This"));
     undoViewAct->setText(tr("&Undo stack"));
     cameraControllerAct->setText(tr("&Camera Controller"));
+    whatsthisAct->setText(tr("What's &This"));
     helpAct->setText(tr("&Help"));
-    onlineHelpAct->setText(tr("&Online Help"));
-    aboutQtAct->setText(tr("About &Qt"));
-    aboutAct->setText(tr("&About"));
+    onlineHelpAct->setText(tr("Online Help"));
+    supportUsAct->setText(tr("Support Us"));
+    aboutQtAct->setText(tr("About Qt"));
+    aboutAct->setText(tr("About"));
 
     // The menus
     fileMenu->setTitle(tr("&File"));
@@ -414,6 +416,22 @@ void MainWindowGUI::retranslateHelpText()
         helpAct->toolTip().prepend(tr("Help"));
     helpAct->setToolTip(infoText);
 
+    infoText =
+        tr("<h4>Online Help</h4> "
+           "<p>This button will bring up the browser with the qStopMotion manual in different languages</p>");
+    onlineHelpAct->setWhatsThis(infoText);
+    infoText =
+        onlineHelpAct->toolTip().prepend(tr("Online Help"));
+    onlineHelpAct->setToolTip(infoText);
+
+    infoText =
+        tr("<h4>Support Us</h4> "
+           "<p>This button will bring up the browser with the qStopMotion support us page</p>");
+    supportUsAct->setWhatsThis(infoText);
+    infoText =
+        supportUsAct->toolTip().prepend(tr("Support Us"));
+    supportUsAct->setToolTip(infoText);
+
     infoText =
         tr("<h4>About Qt</h4> "
            "<p>This will display a small information box where you can read "
@@ -1847,6 +1865,21 @@ void MainWindowGUI::showOnlineHelp()
 }
 
 
+void MainWindowGUI::showSupportUs()
+{
+    qDebug() << "MainWindowGUI::showSupportUs --> Start";
+
+    if ("de" == activeLocale) {
+        QDesktopServices::openUrl(QUrl("http://www.qstopmotion.org/index_deutsch.html#unterstuetzt_uns"));
+    }
+    else {
+        QDesktopServices::openUrl(QUrl("http://www.qstopmotion.org/index.html#support_us"));
+    }
+
+    qDebug() << "MainWindowGUI::showSupportUs --> End";
+}
+
+
 void MainWindowGUI::showAboutDialog()
 {
     AboutDialog *aboutDialog = new AboutDialog(frontend, this);
@@ -2358,7 +2391,7 @@ void MainWindowGUI::createActions()
     iconFile.append(frontend->getIconsDirName());
     iconFile.append(QLatin1String("window.png"));
     helpAct->setIcon(QIcon(iconFile));
-    helpAct->setShortcut(Key_F1);
+    helpAct->setShortcut(ControlModifier + Key_F1);
     helpAct->setIconVisibleInMenu(true);
     connect(helpAct, SIGNAL(triggered()), this, SLOT(showHelpDialog()));
 
@@ -2367,10 +2400,18 @@ void MainWindowGUI::createActions()
     iconFile.append(frontend->getIconsDirName());
     iconFile.append(QLatin1String("window.png"));
     onlineHelpAct->setIcon(QIcon(iconFile));
-    onlineHelpAct->setShortcut(ControlModifier + Key_F1);
+    onlineHelpAct->setShortcut(Key_F1);
     onlineHelpAct->setIconVisibleInMenu(true);
     connect(onlineHelpAct, SIGNAL(triggered()), this, SLOT(showOnlineHelp()));
 
+    supportUsAct = new QAction(this);
+    iconFile.clear();
+    iconFile.append(frontend->getIconsDirName());
+    iconFile.append(QLatin1String("window.png"));
+    supportUsAct->setIcon(QIcon(iconFile));
+    supportUsAct->setIconVisibleInMenu(true);
+    connect(supportUsAct, SIGNAL(triggered()), this, SLOT(showSupportUs()));
+
     aboutQtAct = new QAction(this);
     iconFile.clear();
     iconFile.append(frontend->getIconsDirName());
@@ -2451,6 +2492,7 @@ void MainWindowGUI::createMenus()
     helpMenu->addAction(helpAct);
     helpMenu->addAction(onlineHelpAct);
     helpMenu->addSeparator();
+    helpMenu->addAction(supportUsAct);
     helpMenu->addAction(aboutQtAct);
     helpMenu->addAction(aboutAct);
     menuBar()->addMenu(helpMenu);
