@@ -1,5 +1,5 @@
 /******************************************************************************
- *  Copyright (C) 2005-2016 by                                                *
+ *  Copyright (C) 2005-2017 by                                                *
  *    Bjoern Erik Nilsen (bjoern.nilsen@bjoernen.com),                        *
  *    Fredrik Berg Kjoelstad (fredrikbk@hotmail.com),                         *
  *    Ralf Lange (ralf.lange@longsoft.de)                                     *
@@ -251,6 +251,15 @@ bool QtFrontend::checkApplicationDirectory(char *binDirName)
     otherDirName.append(QLatin1String("/"));
     appGraphicsDirName.append(otherDirName);
 
+    otherDirName.clear();
+    otherDirName.append(appApplicationDirName);
+    otherDirName.append(QLatin1String("share/"));
+    otherDirName.append(PreferencesTool::applicationName);
+    otherDirName.append(QLatin1String("/"));
+    otherDirName.append(PreferencesTool::soundsDirectory);
+    otherDirName.append(QLatin1String("/"));
+    appSoundsDirName.append(otherDirName);
+
 #endif
 
     qDebug() << "QtFrontend::checkApplicationDirectory --> Application Manual Directory:" << appManualDirName;
@@ -459,6 +468,12 @@ const QString QtFrontend::getPicturesDirName()
 }
 
 
+const QString QtFrontend::getSoundsDirName()
+{
+    return this->appSoundsDirName;
+}
+
+
 const QVector<QString> QtFrontend::getLanguages()
 {
     return mw->getLanguages();
@@ -543,6 +558,18 @@ void QtFrontend::setGridColorRGB(int r, int g, int b, int a)
 }
 
 
+bool QtFrontend::getSignal()
+{
+    return mw->getSignal();
+}
+
+
+void QtFrontend::setSignal(bool newState)
+{
+    mw->setSignal(newState);
+}
+
+
 void QtFrontend::showProgress(const QString &operation, unsigned int numOperations)
 {
     mw->showProgress(operation, numOperations);
@@ -725,7 +752,7 @@ void QtFrontend::showCritical(const QString title, const QString &message)
 
 int QtFrontend::runExternalCommand(const QString &command, const QStringList &arguments)
 {
-    ExternalCommandDialog *ec = new ExternalCommandDialog;
+    ExternalCommandDialog *ec = new ExternalCommandDialog(this);
     ec->show();
     ec->run(command, arguments);
     return 0;
@@ -925,6 +952,16 @@ void QtFrontend::startDialog()
 }
 
 
+void QtFrontend::openOnlineHelp(const QString &anchor)
+{
+    qDebug() << "QtFrontend::openOnlineHelp --> Start";
+
+    mw->openOnlineHelp(anchor);
+
+    qDebug() << "QtFrontend::openOnlineHelp --> End";
+}
+
+
 void QtFrontend::setToolBarState(int newState)
 {
     qDebug() << "MainWindowGUI::setToolBarState --> Start";
@@ -947,6 +984,54 @@ void QtFrontend::setRecordingMode(int mode)
 }
 
 
+int QtFrontend::getUnitMode()
+{
+    return mw->getUnitMode();
+}
+
+
+void QtFrontend::setUnitMode(int mode)
+{
+    mw->setUnitMode(mode);
+}
+
+
+int QtFrontend::getUnitCount()
+{
+    return mw->getUnitCount();
+}
+
+
+void QtFrontend::setUnitCount(int count)
+{
+    mw->setUnitCount(count);
+}
+
+
+bool QtFrontend::getBeepState()
+{
+    return mw->getBeepState();
+}
+
+
+void QtFrontend::setBeepState(bool state)
+{
+    mw->setBeepState(state);
+}
+
+
+int QtFrontend::getBeepCount()
+{
+    return mw->getBeepCount();
+}
+
+
+void QtFrontend::setBeepCount(int count)
+{
+    mw->setBeepCount(count);
+}
+
+
 int QtFrontend::getVideoSource()
 {
     return mw->getVideoSource();
@@ -1007,18 +1092,6 @@ void QtFrontend::setMixCount(int count)
 }
 
 
-int QtFrontend::getPlaybackCount()
-{
-    return mw->getPlaybackCount();
-}
-
-
-void QtFrontend::setPlaybackCount(int count)
-{
-    mw->setPlaybackCount(count);
-}
-
-
 int QtFrontend::getOverlayIntensity()
 {
     return mw->getOverlayIntensity();
