@@ -1,5 +1,5 @@
 /******************************************************************************
- *  Copyright (C) 2005-2016 by                                                *
+ *  Copyright (C) 2005-2017 by                                                *
  *    Bjoern Erik Nilsen (bjoern.nilsen@bjoernen.com),                        *
  *    Fredrik Berg Kjoelstad (fredrikbk@hotmail.com),                         *
  *    Ralf Lange (ralf.lange@longsoft.de)                                     *
@@ -167,6 +167,12 @@ public:
      */
     const QString getPicturesDirName();
 
+    /**
+     * Function for getting the sounds directory
+     * @return the sounds directory name string
+     */
+    const QString getSoundsDirName();
+
     /**
      * Getting all possible GUI languages
      * @return A vector with all languages
@@ -257,6 +263,18 @@ public:
      */
     void setGridColorRGB(int r, int g, int b, int a);
 
+    /**
+     * Get the status of the signal feature.
+     * @return The new state of the signal feature.
+     */
+    bool getSignal();
+
+    /**
+     * Set the status of the signal feature.
+     * @param newState The new state of the signal feature.
+     */
+    void setSignal(bool newState);
+
     /**
      * Function for displaying progress on timeconsuming operations.
      * @param infoText the text to display to the user
@@ -451,6 +469,56 @@ public:
      */
     void setRecordingMode(int mode);
 
+    /**
+     * Get the unit mode.
+     * @return The unit mode.
+     */
+    virtual int getUnitMode();
+
+    /**
+     * Set the unit mode.
+     * @param mode The new unit mode.
+     */
+    virtual void setUnitMode(int mode);
+
+    /**
+     * Get the unit count.
+     * @return The unit count.
+     */
+    virtual int getUnitCount();
+
+    /**
+     * Set the unit count.
+     * @param count The new unit count.
+     */
+    virtual void setUnitCount(int count);
+
+    /**
+     * Get the beep checkbox state.
+     * @brief getBeepState
+     * @return The actual beep checkbox state
+     */
+    virtual bool getBeepState();
+
+    /**
+     * Set the beep checkbox state.
+     * @brief setBeepState
+     * @param state The new beep checkbox state.
+     */
+    virtual void setBeepState(bool state);
+
+    /**
+     * Get the beep unit count.
+     * @return The beep unit count.
+     */
+    virtual int getBeepCount();
+
+    /**
+     * Set the beep unit count.
+     * @param count The new beep unit count.
+     */
+    virtual void setBeepCount(int count);
+
     /**
      * Get the video source index.
      * @return video source index
@@ -516,18 +584,6 @@ public:
      */
     void setMixCount(int count);
 
-    /**
-     * Get the playback count.
-     * @return The playback count.
-     */
-    int getPlaybackCount();
-
-    /**
-     * Set the playback count.
-     * @param count The new playback count.
-     */
-    void setPlaybackCount(int count);
-
     /**
      * Get the overlay intensity value.
      * @return The overlay intensity value.
@@ -629,6 +685,12 @@ public:
      */
     void startDialog();
 
+    /**
+     * Open the online help in the default internet browser
+     * @param anchor The anchor in the manual to go to after the manual is opend
+     */
+    void openOnlineHelp(const QString &anchor);
+
 protected slots:
 
 private:
@@ -646,6 +708,7 @@ private:
     QString          appGraphicsDirName;
     QString          appIconsDirName;
     QString          appPicturesDirName;
+    QString          appSoundsDirName;
 
     void initializePreferences();
     void setDefaultPreferences();
