@@ -1,5 +1,5 @@
 /******************************************************************************
- *  Copyright (C) 2010-2016 by                                                *
+ *  Copyright (C) 2010-2017 by                                                *
  *    Ralf Lange (ralf.lange@longsoft.de)                                     *
  *                                                                            *
  *  This program is free software; you can redistribute it and/or modify      *
@@ -68,11 +68,16 @@ void ToolBar::makeGUI()
     iconFile.append(QLatin1String("frames.png"));
     framesIcon->setPixmap(QPixmap(iconFile));
 
-    overlaySlider = new QSlider(Qt::Horizontal);
-    connect(overlaySlider, SIGNAL(valueChanged(int)), this, SLOT(overlaySliderChanged(int)));
-    overlaySlider->setMinimum(0);
-    overlaySlider->setMaximum(255);
-    overlaySlider->setValue(100);
+    overlaySlider = new QwtSlider(Qt::Horizontal);
+    overlaySlider->setScalePosition(QwtSlider::NoScale);
+    overlaySlider->setTrough(false);
+    overlaySlider->setGroove(true);
+    overlaySlider->setHandleSize(QSize(12, 25));
+    overlaySlider->setScale(0.0, 250.0);
+    overlaySlider->setTotalSteps(10);
+    overlaySlider->setSingleSteps(25);
+    overlaySlider->setValue(100.0);
+    connect(overlaySlider, SIGNAL(sliderReleased()), this, SLOT(overlaySliderChanged()));
 
     cameraIcon = new QLabel();
     iconFile.clear();
@@ -87,6 +92,7 @@ void ToolBar::makeGUI()
     iconFile.append(frontend->getIconsDirName());
     iconFile.append(QLatin1String("firstexposure.png"));
     toBeginButton->setIcon(QPixmap(iconFile));
+    toBeginButton->setIconSize(QSize(30,30));
     // toBeginButton->setFlat(true);
     // toBeginButton->setFocusPolicy( Qt::NoFocus );
     connect(toBeginButton, SIGNAL(clicked()), this, SLOT(selectFirstFrame()));
@@ -97,6 +103,7 @@ void ToolBar::makeGUI()
     iconFile.append(frontend->getIconsDirName());
     iconFile.append(QLatin1String("previousexposure.png"));
     previousFrameButton->setIcon(QPixmap(iconFile));
+    previousFrameButton->setIconSize(QSize(30,30));
     // previousFrameButton->setFlat(true);
     connect(previousFrameButton, SIGNAL(clicked()), this, SLOT(selectPreviousFrame()));
     previousFrameButton->setEnabled(false);
@@ -106,6 +113,7 @@ void ToolBar::makeGUI()
     iconFile.append(frontend->getIconsDirName());
     iconFile.append(QLatin1String("capture.png"));
     captureButton->setIcon(QPixmap(iconFile));
+    captureButton->setIconSize(QSize(30,30));
     // captureButton->setFlat(true);
     // captureButton->setSizePolicy(QSizePolicy::Maximum, QSizePolicy::Minimum);
     captureButton->setEnabled(false);
@@ -115,6 +123,7 @@ void ToolBar::makeGUI()
     iconFile.append(frontend->getIconsDirName());
     iconFile.append(QLatin1String("play.png"));
     playButton->setIcon(QPixmap(iconFile));
+    playButton->setIconSize(QSize(30,30));
     // playButton->setFlat(true);
     connect(playButton, SIGNAL(clicked()), this, SLOT(runAnimation()));
     playButton->setEnabled(false);
@@ -124,6 +133,7 @@ void ToolBar::makeGUI()
     iconFile.append(frontend->getIconsDirName());
     iconFile.append(QLatin1String("nextexposure.png"));
     nextFrameButton->setIcon(QPixmap(iconFile));
+    nextFrameButton->setIconSize(QSize(30,30));
     // nextFrameButton->setFlat(true);
     // nextFrameButton->setSizePolicy(QSizePolicy::Maximum, QSizePolicy::Minimum);
     connect(nextFrameButton, SIGNAL(clicked()), this, SLOT(selectNextFrame()));
@@ -134,6 +144,7 @@ void ToolBar::makeGUI()
     iconFile.append(frontend->getIconsDirName());
     iconFile.append(QLatin1String("lastexposure.png"));
     toEndButton->setIcon(QPixmap(iconFile));
+    toEndButton->setIconSize(QSize(30,30));
     // toEndButton->setFlat(true);
     // toEndButton->setSizePolicy(QSizePolicy::Maximum, QSizePolicy::Minimum);
     connect(toEndButton, SIGNAL(clicked()), this, SLOT(selectLastFrame()));
@@ -549,8 +560,10 @@ void ToolBar::toggleLooping()
 }
 
 
-void ToolBar::overlaySliderChanged(int value)
+void ToolBar::overlaySliderChanged()
 {
+    int value = (int)(overlaySlider->value());
+
     frontend->getProject()->setOverlayIntensity(value);
 }
 
