@@ -34,8 +34,8 @@
 
 const QString PreferencesTool::applicationShowName = QLatin1String("qStopMotion");
 const QString PreferencesTool::applicationName = QLatin1String("qstopmotion");
-const QString PreferencesTool::applicationVersion = QLatin1String("2.4.0");
-const QString PreferencesTool::applicationYear = QLatin1String("2017");
+const QString PreferencesTool::applicationVersion = QLatin1String("2.4.1");
+const QString PreferencesTool::applicationYear = QLatin1String("2018");
 const QString PreferencesTool::preferencesVersion = QLatin1String("0.9");
 const QString PreferencesTool::preferencesSuffix = QLatin1String("qsmp");
 const QString PreferencesTool::preferencesName = QLatin1String("preferences");
@@ -452,11 +452,11 @@ void PreferencesTool::setBasicPreferenceDefaults()
     setBooleanPreference("preferences", "defaultusedefaultoutputfile", DomainFacade::USEDEFAULTOUTPUTFILENAMEDEFAULT);
     // Grabber defaults
     setBooleanPreference("preferences", "v4l2grabber", Frontend::V4L2GRABBERDEFAULT);
-    setBooleanPreference("preferences", "v4l2controller", Frontend::V4L2CONTROLERDEFAULT);
+    setBooleanPreference("preferences", "v4l2controller", Frontend::V4L2CONTROLLERDEFAULT);
     setBooleanPreference("preferences", "mediafoundationgrabber", Frontend::MEDIAFOUNDATIONGRABBERDEFAULT);
-    setBooleanPreference("preferences", "mediafoundationcontroller", Frontend::MEDIAFOUNDATIONCONTROLERDEFAULT);
+    setBooleanPreference("preferences", "mediafoundationcontroller", Frontend::MEDIAFOUNDATIONCONTROLLERDEFAULT);
     setBooleanPreference("preferences", "gphoto2grabber", Frontend::GPHOTO2GRABBERDEFAULT);
-    setBooleanPreference("preferences", "gphoto2controller", Frontend::GPHOTO2CONTROLERDEFAULT);
+    setBooleanPreference("preferences", "gphoto2controller", Frontend::GPHOTO2CONTROLLERDEFAULT);
 }
 
 
