@@ -103,6 +103,10 @@
         <source>Czech</source>
         <translation>Čeština</translation>
     </message>
+    <message>
+        <source>Greek</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>AnimationProject</name>
@@ -177,7 +181,7 @@ rozhodnete pro přehrání, přehrána bez zvuku.</translation>
     </message>
     <message>
         <source>Camera Control</source>
-        <translation>Řízení kamery</translation>
+        <translation>Ovládání kamery</translation>
     </message>
     <message>
         <source>&amp;Close</source>
@@ -305,90 +309,90 @@ rozhodnete pro přehrání, přehrána bez zvuku.</translation>
     </message>
     <message>
         <source>Help</source>
-        <translation type="unfinished">Nápověda</translation>
+        <translation>Nápověda</translation>
     </message>
 </context>
 <context>
-    <name>ControlerWidget</name>
+    <name>ControllerWidget</name>
     <message>
         <source>Below you can set which features of the camera should be used in the camera control dialog.</source>
-        <translation type="unfinished"></translation>
+        <translation>Níže můžete vybrat, které funkce kamery se mají použít v dialogu pro ovládání kamery.</translation>
     </message>
     <message>
         <source>Image quality controls</source>
-        <translation type="unfinished"></translation>
+        <translation>Ovládání jakosti obrázku</translation>
     </message>
     <message>
         <source>Brightness control</source>
-        <translation type="unfinished"></translation>
+        <translation>Ovládání jasu</translation>
     </message>
     <message>
         <source>Contrast control</source>
-        <translation type="unfinished"></translation>
+        <translation>Ovládání kontrastu</translation>
     </message>
     <message>
         <source>Saturation control</source>
-        <translation type="unfinished"></translation>
+        <translation>Ovládání sytosti</translation>
     </message>
     <message>
         <source>Hue control</source>
-        <translation type="unfinished"></translation>
+        <translation>Ovládání barevného tónu</translation>
     </message>
     <message>
         <source>Gamma control</source>
-        <translation type="unfinished"></translation>
+        <translation>Ovládání gamy</translation>
     </message>
     <message>
         <source>Sharpness control</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Gain control</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Camera controls</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Exposure control</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Zoom control</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Focus control</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Pan control</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Tilt control</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Iris control</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Roll control</source>
-        <translation type="unfinished"></translation>
+        <translation>Ovládání ostrosti</translation>
     </message>
     <message>
         <source>Backlight compensation control</source>
-        <translation type="unfinished"></translation>
+        <translation>Ovládání vyrovnání osvětlení zezadu</translation>
     </message>
     <message>
         <source>White balance control</source>
-        <translation type="unfinished"></translation>
+        <translation>Ovládání vyvážení bílé</translation>
+    </message>
+    <message>
+        <source>Gain control</source>
+        <translation>Ovládání zesílení</translation>
     </message>
     <message>
         <source>Color enable control</source>
-        <translation type="unfinished"></translation>
+        <translation>Ovládání povolení barvy</translation>
+    </message>
+    <message>
+        <source>Camera controls</source>
+        <translation>Ovládání kamery</translation>
+    </message>
+    <message>
+        <source>Exposure control</source>
+        <translation>Ovládání osvitu</translation>
+    </message>
+    <message>
+        <source>Zoom control</source>
+        <translation>Ovládání přiblížení a oddálení</translation>
+    </message>
+    <message>
+        <source>Focus control</source>
+        <translation>Ovládání ostření</translation>
+    </message>
+    <message>
+        <source>Pan control</source>
+        <translation>Ovládání smyku (pohyb kamery)</translation>
+    </message>
+    <message>
+        <source>Tilt control</source>
+        <translation>Ovládání naklonění</translation>
+    </message>
+    <message>
+        <source>Iris control</source>
+        <translation>Ovládání duhovky</translation>
+    </message>
+    <message>
+        <source>Roll control</source>
+        <translation>Ovládání točení</translation>
     </message>
 </context>
 <context>
@@ -443,7 +447,7 @@ rozhodnete pro přehrání, přehrána bez zvuku.</translation>
     </message>
     <message>
         <source>Help</source>
-        <translation type="unfinished">Nápověda</translation>
+        <translation>Nápověda</translation>
     </message>
 </context>
 <context>
@@ -631,7 +635,7 @@ rozhodnete pro přehrání, přehrána bez zvuku.</translation>
     </message>
     <message>
         <source>Help</source>
-        <translation type="unfinished">Nápověda</translation>
+        <translation>Nápověda</translation>
     </message>
 </context>
 <context>
@@ -678,11 +682,11 @@ rozhodnete pro přehrání, přehrána bez zvuku.</translation>
     </message>
     <message>
         <source>Help</source>
-        <translation type="unfinished">Nápověda</translation>
+        <translation>Nápověda</translation>
     </message>
     <message>
-        <source>Camera Controler</source>
-        <translation type="unfinished"></translation>
+        <source>Camera Controller</source>
+        <translation>Ovládací spínač kamery</translation>
     </message>
 </context>
 <context>
@@ -729,11 +733,11 @@ rozhodnete pro přehrání, přehrána bez zvuku.</translation>
     </message>
     <message>
         <source>Signal Functionality</source>
-        <translation type="unfinished"></translation>
+        <translation>Funkce signálu</translation>
     </message>
     <message>
         <source>Take Picture Signal</source>
-        <translation type="unfinished"></translation>
+        <translation>Signál k udělání záběru</translation>
     </message>
 </context>
 <context>
@@ -1067,7 +1071,7 @@ nabídce pro nastavení.</translation>
     </message>
     <message>
         <source>&amp;About</source>
-        <translation>&amp;O programu</translation>
+        <translation type="vanished">&amp;O programu</translation>
     </message>
     <message>
         <source>Remove Scene</source>
@@ -1115,7 +1119,7 @@ nabídce pro nastavení.</translation>
     </message>
     <message>
         <source>Exposure ID: </source>
-        <translation>ID snímku: </translation>
+        <translation>ID osvitu snímku: </translation>
     </message>
     <message>
         <source>Cancel</source>
@@ -1179,7 +1183,7 @@ teprve, až vyberete nějaký kodér. Chcete to udělat nyní?</translation>
     </message>
     <message>
         <source>About &amp;Qt</source>
-        <translation>O &amp;Qt</translation>
+        <translation type="vanished">O &amp;Qt</translation>
     </message>
     <message>
         <source>Properties</source>
@@ -1392,8 +1396,20 @@ Install the encoder or select another one!</source>
 Kodér nainstalujte nebo vyberte jiný!</translation>
     </message>
     <message>
-        <source>&amp;Online Help</source>
-        <translation type="unfinished"></translation>
+        <source>Online Help</source>
+        <translation>Nápověda na internetu</translation>
+    </message>
+    <message>
+        <source>Support Us</source>
+        <translation>Podpořte nás</translation>
+    </message>
+    <message>
+        <source>&lt;h4&gt;Online Help&lt;/h4&gt; &lt;p&gt;This button will bring up the browser with the qStopMotion manual in different languages&lt;/p&gt;</source>
+        <translation>&lt;h4&gt;Nápověda na internetu&lt;/h4&gt; &lt;p&gt;Tímto tlačítkem se vyvolá prohlížeč s příručkou k qStopMotion v různých jazycích&lt;/p&gt;</translation>
+    </message>
+    <message>
+        <source>&lt;h4&gt;Support Us&lt;/h4&gt; &lt;p&gt;This button will bring up the browser with the qStopMotion support us page&lt;/p&gt;</source>
+        <translation>&lt;h4&gt;Podpořte nás&lt;/h4&gt; &lt;p&gt;Tímto tlačítkem se vyvolá prohlížeč se stránkou k qStopMotion Podpořte nás&lt;/p&gt;</translation>
     </message>
 </context>
 <context>
@@ -1461,7 +1477,7 @@ Kodér nainstalujte nebo vyberte jiný!</translation>
     </message>
     <message>
         <source>Help</source>
-        <translation type="unfinished">Nápověda</translation>
+        <translation>Nápověda</translation>
     </message>
 </context>
 <context>
@@ -1708,59 +1724,59 @@ Kodér nainstalujte nebo vyberte jiný!</translation>
     </message>
     <message>
         <source>Time-lapse capture</source>
-        <translation type="unfinished"></translation>
+        <translation>Časosběrné zachytávání</translation>
     </message>
     <message>
         <source>Time-lapse</source>
-        <translation type="unfinished"></translation>
+        <translation>Časosběr</translation>
     </message>
     <message>
         <source>Unit:</source>
-        <translation type="unfinished"></translation>
+        <translation>Jednotka:</translation>
     </message>
     <message>
         <source>Seconds</source>
-        <translation type="unfinished"></translation>
+        <translation>Sekundy</translation>
     </message>
     <message>
         <source>Minutes</source>
-        <translation type="unfinished"></translation>
+        <translation>Minuty</translation>
     </message>
     <message>
         <source>Hours</source>
-        <translation type="unfinished"></translation>
+        <translation>Hodiny</translation>
     </message>
     <message>
         <source>Days</source>
-        <translation type="unfinished"></translation>
+        <translation>Dny</translation>
     </message>
     <message>
         <source>Beep</source>
-        <translation type="unfinished"></translation>
+        <translation>Pípnutí</translation>
     </message>
     <message>
         <source>seconds before picture:</source>
-        <translation type="unfinished"></translation>
+        <translation>sekund před záběrem:</translation>
     </message>
     <message>
         <source>Seconds between pictures</source>
-        <translation type="unfinished"></translation>
+        <translation>Sekund mezi záběry</translation>
     </message>
     <message>
         <source>Minutes between pictures</source>
-        <translation type="unfinished"></translation>
+        <translation>Minut mezi záběry</translation>
     </message>
     <message>
         <source>Hours between pictures</source>
-        <translation type="unfinished"></translation>
+        <translation>Hodin mezi záběry</translation>
     </message>
     <message>
         <source>Days between pictures</source>
-        <translation type="unfinished"></translation>
+        <translation>Dnů mezi záběry</translation>
     </message>
     <message>
         <source>&lt;h4&gt;Number of images&lt;/h4&gt; &lt;p&gt;By changing the value in this slidebar you can specify how many images backwards in the animation which should be mixed on top of the camera.&lt;/p&gt; &lt;p&gt;By mixing the previous image(s) onto the camera you can more easily see how the next shot will be in relation to the other, therby making a smoother stop motion animation!&lt;/p&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation>&lt;h4&gt;Počet obrázků&lt;/h4&gt; &lt;p&gt;Tímto posuvníkem (změnou hodnoty) můžete nastavit, kolik předcházejících obrázků v animaci se má zařadit v obrazu kamery.&lt;/p&gt; &lt;p&gt;Tím (míšením předchozího obrázku(ů) do kamery) lépe uvidíte, jak je následující obrázek ve vztahu k předcházejícím obrázkům. To umožňuje stejnoměrný (hladší) průběh pohybu!&lt;/p&gt;</translation>
     </message>
 </context>
 <context>
@@ -1884,59 +1900,59 @@ Potřebujete oprávnění ke čtení, zápisu a spouštění adresáře .qstopmo
     </message>
     <message>
         <source>Recording mode</source>
-        <translation type="unfinished"></translation>
+        <translation>Režim nahrávání</translation>
     </message>
     <message>
         <source>Time-lapse capture</source>
-        <translation type="unfinished"></translation>
+        <translation>Časosběrné zachytávání</translation>
     </message>
     <message>
         <source>Time-lapse</source>
-        <translation type="unfinished"></translation>
+        <translation>Časosběr</translation>
     </message>
     <message>
         <source>Unit:</source>
-        <translation type="unfinished"></translation>
+        <translation>Jednotka:</translation>
     </message>
     <message>
         <source>Seconds</source>
-        <translation type="unfinished"></translation>
+        <translation>Sekundy</translation>
     </message>
     <message>
         <source>Minutes</source>
-        <translation type="unfinished"></translation>
+        <translation>Minuty</translation>
     </message>
     <message>
         <source>Hours</source>
-        <translation type="unfinished"></translation>
+        <translation>Hodiny</translation>
     </message>
     <message>
         <source>Days</source>
-        <translation type="unfinished"></translation>
+        <translation>Dny</translation>
     </message>
     <message>
         <source>Beep</source>
-        <translation type="unfinished"></translation>
+        <translation>Pípnutí</translation>
     </message>
     <message>
         <source>seconds before picture:</source>
-        <translation type="unfinished"></translation>
+        <translation>sekund před záběrem:</translation>
     </message>
     <message>
         <source>Seconds between pictures</source>
-        <translation type="unfinished"></translation>
+        <translation>Sekund mezi záběry</translation>
     </message>
     <message>
         <source>Minutes between pictures</source>
-        <translation type="unfinished"></translation>
+        <translation>Minut mezi záběry</translation>
     </message>
     <message>
         <source>Hours between pictures</source>
-        <translation type="unfinished"></translation>
+        <translation>Hodin mezi záběry</translation>
     </message>
     <message>
         <source>Days between pictures</source>
-        <translation type="unfinished"></translation>
+        <translation>Dnů mezi záběry</translation>
     </message>
 </context>
 <context>
@@ -1990,7 +2006,7 @@ Potřebujete oprávnění ke čtení, zápisu a spouštění adresáře .qstopmo
     </message>
     <message>
         <source>Help</source>
-        <translation type="unfinished">Nápověda</translation>
+        <translation>Nápověda</translation>
     </message>
 </context>
 <context>
@@ -2075,15 +2091,15 @@ Potřebujete oprávnění ke čtení, zápisu a spouštění adresáře .qstopmo
     </message>
     <message>
         <source>Zoom value (%):</source>
-        <translation type="unfinished"></translation>
+        <translation>Hodnota zvětšení:</translation>
     </message>
     <message>
         <source>Min</source>
-        <translation type="unfinished">Nejmenší</translation>
+        <translation>Nejmenší</translation>
     </message>
     <message>
         <source>Max</source>
-        <translation type="unfinished">Největší</translation>
+        <translation>Největší</translation>
     </message>
 </context>
 <context>
